/*!
 *     @header SpinnersNTips
 *
 *   @abstract Sample code for the ToolTip, SpinButton, and SpinControl classes.
 * @discussion
 *             Copyright &copy; 2000 Carlos Hasan
 *
 *             This software is provided 'as-is', without any express or implied
 *             warranty. In no event will the author be held liable for any
 *             damages arising from the use of this software. Permission is
 *             granted to anyone to use this software for any purpose, including
 *             commercial applications, and to alter it and redistribute it
 *             freely, subject to the following restrictions:
 *
 *             1. The origin of this software must not be misrepresented; you
 *             must not claim that you wrote the original software. If you use
 *             this software in a product, an acknowledgment in the product
 *             documentation would be appreciated but is not required.
 *
 *             2. Altered source versions must be plainly marked as such, and
 *             must not be misrepresented as being the original software.
 *
 *             3. This notice may not be removed or altered from any source
 *             distribution.
 */

#include <Application.h>
#include <Window.h>
#include <Box.h>
#include <Button.h>
#include <StringView.h>
#include <ToolTip.h>
#include <SpinButton.h>
#include <SpinControl.h>
#include <stdio.h>

using namespace BeUnited;


/* SampleWindow */

enum {
	kSpinButtonChanged = 'spBt',
	kSpinControlChanged = 'spCt'
};

class SampleWindow : public BWindow {
	public:
		SampleWindow();
		
		virtual void MessageReceived(BMessage *message);
		virtual bool QuitRequested();
	
	private:
		BBox *fBox;
		BButton *fButton;
		BStringView *fLabel;
		SpinControl *fSpinControl;
		SpinButton *fSpinButton;
		ToolTip *fToolTip;
};

SampleWindow::SampleWindow() :
	BWindow(BRect(150, 150, 350, 350), "Sample",
		B_TITLED_WINDOW, 0 ),
	fBox(NULL), fButton(NULL), fLabel(NULL), fSpinControl(NULL),
	fSpinButton(NULL), fToolTip(NULL)
{
	fBox = new BBox(BRect(0, 0, 200, 200), "Box", B_FOLLOW_ALL_SIDES,
		B_WILL_DRAW | B_FRAME_EVENTS | B_NAVIGABLE_JUMP, B_PLAIN_BORDER);
	AddChild(fBox);

	fButton = new BButton(BRect(110, 160, 180, 180), "Button",
		"Close", new BMessage(B_QUIT_REQUESTED), B_FOLLOW_RIGHT | B_FOLLOW_BOTTOM);
	fButton->MakeDefault(true);
	fBox->AddChild(fButton);

	fLabel = new BStringView(BRect(10, 10, 190, 40), "StringView",
		"Point over here and wait one second.");
	fBox->AddChild(fLabel);
	
	fSpinControl = new SpinControl(BRect(10, 60, 140, 80), "SpinControl",
		"Number of bugs:", new BMessage(kSpinControlChanged), 0, 100, 0, 10);
	fSpinControl->SetDivider(fSpinControl->StringWidth(fSpinControl->Label()) + 10);
	fBox->AddChild(fSpinControl);
	
	fSpinButton = new SpinButton(BRect(100, 100, 115, 120), "SpinButton",
		new BMessage(kSpinButtonChanged), 0, 10, 0, 1);
	fBox->AddChild(fSpinButton);
		
	fToolTip = new ToolTip(this, "ToolTip");
	fToolTip->SetText(fBox, "Move the pointer and do something! :-)");
	fToolTip->SetText(fButton, "Push me to close the window");
	fToolTip->SetText(fLabel, "This is a tooltip!");
	fToolTip->SetText(fSpinControl, "Select me and move the mouse wheel");
	fToolTip->SetText(fSpinButton, "Drag the spin button up and down...");
}

void SampleWindow::MessageReceived(BMessage *message)
{
	char buffer[128];

	if (message->what == kSpinButtonChanged) {
		sprintf(buffer, "The spin button was changed to %ld!", fSpinButton->Value());
		fLabel->SetText(buffer);
		fToolTip->SetText(fSpinButton, "You can use the keyboard to change the spin button");
	}
	else if (message->what == kSpinControlChanged) {
		sprintf(buffer, "You found %ld bugs?", fSpinControl->Value());
		fLabel->SetText(buffer);
	}
	else {
		BWindow::MessageReceived(message);
	}
}

bool SampleWindow::QuitRequested()
{
	be_app->PostMessage( B_QUIT_REQUESTED );
	return true;
}


/* SampleApplication */

class SampleApplication : public BApplication {
	public:
		SampleApplication(const char *signature);
		
		virtual void ReadyToRun();
};

SampleApplication::SampleApplication(const char *signature) :
	BApplication(signature)
{
}

void SampleApplication::ReadyToRun()
{
	BWindow *window = new SampleWindow();
	window->Show();
}


int main()
{
	SampleApplication application("application/x-vnd.BeUnited.SpinnersNTips");
	application.Run();
	return 0;
}
